@@ -18,6 +18,7 @@ from docutils.core import publish_file
 import optparse
 import os
 import pkg_resources
+import re
 import shutil
 from sphinx.application import Sphinx
 import sys
@@ -27,6 +28,7 @@ from dataflake.docbuilder.rcs import SVNClient
 from dataflake.docbuilder.utils import shell_cmd
 
 SUPPORTED_VCS = {'svn': SVNClient, 'hg': HGClient}
+VCS_SPEC_MATCH = re.compile(r'^\[(.*)\](.*)$')
 
 OPTIONS = (
   optparse.make_option( '-s'
@@ -35,13 +37,6 @@ OPTIONS = (
                       , dest='urls'
                       , help='VCS URL (can be used multiple times)'
                       ),
-  optparse.make_option( '-r'
-                      , '--rcs-system'
-                      , action='store'
-                      , dest='rcs'
-                      , help='Revision control system in use. Valid values are "svn" and "hg". Default is "svn".'
-                      , default='svn'
-                      ),
   optparse.make_option( '-g'
                       , '--grouping'
                       , action='append'
@@ -121,13 +116,6 @@ class DocsBuilder(object):
              not self.options.z3csphinx_output_directory ):
             parser.error('Please provide package VCS URLs')
 
-        if self.options.rcs.lower() not in SUPPORTED_VCS:
-            msg = 'Unsupported revision control system "%s"'
-            parser.error(msg % self.options.rcs)
-
-        rcs_class = SUPPORTED_VCS[self.options.rcs.lower()]
-        self.rcs = rcs_class(self.options.trunk_name, self.options.tags_name)
-
         if not self.options.workingdir:
             parser.error('Please provide a workingdir directory path')
 
@@ -168,12 +156,24 @@ class DocsBuilder(object):
         [grouped.extend(x) for x in self.group_map.values()]
 
         for url in self.options.urls or []:
-            package_name = self.rcs.name_from_url(url)
+            re_match = VCS_SPEC_MATCH.search(url)
+            if re_match is not None:
+                rcs_class = SUPPORTED_VCS.get(re_match.groups()[0].lower())
+                package_url = re_match.groups()[1].strip()
+            else:
+                rcs_class = SUPPORTED_VCS.get('svn')
+                package_url = url
+
+            if rcs_class is None:
+                continue
+
+            rcs = rcs_class(self.options.trunk_name, self.options.tags_name)
+            package_name = rcs.name_from_url(package_url)
             if package_name not in self.z3csphinx_packages:
-                info = self.rcs.checkout_or_update( url
-                                                  , self.options.workingdir
-                                                  , self.options.trunk_only
-                                                  )
+                info = rcs.checkout_or_update( package_url
+                                             , self.options.workingdir
+                                             , self.options.trunk_only
+                                             )
             else:
                 info = {}
 
@@ -218,9 +218,14 @@ class DocsBuilder(object):
             for package_name in package_names:
                 tags_list = []
                 tag_names = self.packages[package_name].keys()
-                tag_names.sort(key=str.lower)
+                tag_names.sort(key=pkg_resources.parse_version)
                 tag_names.reverse()
 
+                # Make sure trunk stays at the top
+                if self.options.trunk_name in tag_names:
+                    tag_names.remove(self.options.trunk_name)
+                    tag_names.insert(0, self.options.trunk_name)
+
                 for tag_name in tag_names:
                     html_output_folder = self.packages[package_name][tag_name]
                     tag_data = { 'package_name': package_name
